# Copyright (C) 2013 Julian Metzler
# See the LICENSE file for the full license.

name = "TweetPony"
version = "1.2.5"
description = "A Twitter library for Python"
license = "AGPLv3"
author = "Julian Metzler"
author_email = "contact@mezgrman.de"
requires = ['requests<=1.2.0']
url = "https://github.com/Mezgrman/TweetPony"
keywords = "twitter library api wrapper pony"
